package
Version:
v0.0.0-...-cee06b0
Opens a new window with list of versions in this module.
Published: Oct 14, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func MapSlice[T, S any](source []T, mapper func(T) S) []S
func ReverseSlice[S ~[]E, E any](s S)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.